Module error

Module error 

Structs

AppError
ErrorListResult
ErrorOccurrence
ErrorTrendPoint
Error trend point for charting
IncomingError
IncomingSourceContext
SourceContext

Functions

count_filtered
count_since
delete_occurrences_before
error_trend
Get hourly error occurrence counts for a specific error (for trend sparklines)
error_trend_24h
Get simplified 24h trend for an error (returns just the hourly counts as a string for sparkline)
find
hourly_error_stats
Get overall hourly error counts (for error index chart)
insert
list
list_filtered
list_paginated
occurrences
update_status