Structs
- AppError
- Error
List Result - Error
Occurrence - Error
Trend Point - Error trend point for charting
- Incoming
Error - Incoming
Source Context - Source
Context
Functions
- count_
filtered - count_
since - delete_
occurrences_ before - error_
trend - Get hourly error occurrence counts for a specific error (for trend sparklines)
- error_
trend_ 24h - Get simplified 24h trend for an error (returns just the hourly counts as a string for sparkline)
- find
- hourly_
error_ stats - Get overall hourly error counts (for error index chart)
- insert
- list
- list_
filtered - list_
paginated - occurrences
- update_
status