pub fn backfill_errors_from_spans(pool: &DbPool) -> Result<usize>
Backfill errors from existing spans that have exception events This is useful for extracting errors from spans that were ingested before error extraction was added